import { UriComponents } from '@vscode-alt/monaco-editor/esm/vs/base/common/uri';
import { DocumentSelector } from 'cdeops/client';
import { Position } from './plainTypes';
import { TextDocument } from 'cdeops';
export interface UriState extends UriComponents {
    $mid: number;
    fsPath: string;
    external: string;
}
/**
 * A literal to identify a text document in the client.
 */
export interface TextDocumentIdentifier {
    /**
     * The text document's URI.
     */
    uri: string;
}
/**
 * A parameter literal used in requests to pass a text document and a position inside that
 * document.
 */
export interface TextDocumentPositionParameters {
    /**
     * The text document.
     */
    textDocument: TextDocumentIdentifier;
    /**
     * The position inside the text document.
     */
    position: Position;
}
/**
 * General text document registration options.
 */
export interface TextDocumentRegistrationOptions {
    /**
     * A document selector to identify the scope of the registration.
     */
    documentSelector: DocumentSelector;
}
/**
 * Returns whether any of the document selectors match (or "select") the document.
 */
export declare function match(selectors: DocumentSelector | IterableIterator<DocumentSelector>, document: Pick<TextDocument, 'uri' | 'languageId'>): boolean;
/**
 * Returns the score that indicates "how well" the document selector matches a document (by its URI and language
 * ID). A higher score indicates a more specific match. The score is a heuristic.
 *
 * For example, a document selector ['*'] matches all documents, so it is not a very specific match for any
 * document (but it *does* match all documents). Its score will be lower than a more specific match, such as the
 * document selector [{language: 'python'}] against a Python document.
 *
 * Taken from
 * https://github.com/Microsoft/vscode/blob/3d35801127f0a62d58d752bc613506e836c5d120/src/vs/editor/common/modes/languageSelector.ts#L24.
 */
export declare function score(selector: DocumentSelector, candidateUri: URL, candidateLanguage: string): number;
