import { Event } from '@vscode-alt/monaco-editor/esm/vs/base/common/event';
import { URI } from '@vscode-alt/monaco-editor/esm/vs/base/common/uri';
import { IExtensionIdentifier } from '../generated-models';
import { IMouseWheelEvent } from '@vscode-alt/monaco-editor/esm/vs/base/browser/mouseEvent';
import { Dimension } from '@vscode-alt/monaco-editor/esm/vs/base/browser/dom';
import * as modes from '@vscode-alt/monaco-editor/esm/vs/editor/common/modes';
import { IDisposable } from '@vscode-alt/monaco-editor/esm/vs/base/common/lifecycle';
export interface WebviewIcons {
    readonly light: URI;
    readonly dark: URI;
}
/**
 * Handles the creation of webview elements.
 */
export interface IWebviewService {
    readonly activeWebView: Webview | undefined;
    createWebviewElement(id: string, options: WebviewOptions, contentOptions: WebviewContentOptions, extension: WebviewExtensionDescription | undefined): WebviewElement;
    createWebviewOverlay(id: string, options: WebviewOptions, contentOptions: WebviewContentOptions, extension: WebviewExtensionDescription | undefined): WebviewOverlay;
    setIcons(id: string, value: WebviewIcons | undefined): void;
}
export declare const enum WebviewContentPurpose {
    NotebookRenderer = "notebookRenderer",
    CustomEditor = "customEditor"
}
export interface WebviewOptions {
    readonly purpose?: WebviewContentPurpose;
    readonly customClasses?: string;
    readonly enableFindWidget?: boolean;
    readonly tryRestoreScrollPosition?: boolean;
    readonly retainContextWhenHidden?: boolean;
}
export interface WebviewContentOptions {
    readonly allowMultipleAPIAcquire?: boolean;
    readonly allowScripts?: boolean;
    readonly localResourceRoots?: ReadonlyArray<URI>;
    readonly portMapping?: ReadonlyArray<modes.IWebviewPortMapping>;
    readonly enabledCommandUris?: boolean;
}
export interface WebviewExtensionDescription {
    readonly location: URI;
    readonly id: IExtensionIdentifier;
}
export interface IDataLinkClickEvent {
    dataURL: string;
    downloadName?: string;
}
export interface Webview extends IDisposable {
    readonly id: string;
    html: string;
    contentOptions: WebviewContentOptions;
    localResourcesRoot: URI[];
    extension: WebviewExtensionDescription | undefined;
    initialScrollProgress: number;
    state: string | undefined;
    readonly isFocussed: boolean;
    readonly onDidFocus: Event<void>;
    readonly onDidBlur: Event<void>;
    readonly ondDidDispose: Event<void>;
    readonly onDidClickLink: Event<string>;
    readonly onDidScroll: Event<{
        scrollYPercentage: number;
    }>;
    readonly onDidWheel: Event<IMouseWheelEvent>;
    readonly onDidUpdateState: Event<string | undefined>;
    readonly onDidReload: Event<void>;
    readonly onMessage: Event<any>;
    readonly onMissingCsp: Event<IExtensionIdentifier>;
    postMessage(data: any): void;
    focus(): void;
    reload(): void;
    showFind(): void;
    hideFind(): void;
    runFindAction(previous: boolean): void;
    selectAll(): void;
    copy(): void;
    paste(): void;
    cut(): void;
    undo(): void;
    redo(): void;
    windowDidDragStart(): void;
    windowDidDragEnd(): void;
}
/**
 * Basic webview rendered in the dom
 */
export interface WebviewElement extends Webview {
    mountTo(parent: HTMLElement): void;
}
/**
 * Dynamically created webview drawn over another element.
 */
export interface WebviewOverlay extends Webview {
    readonly container: HTMLElement;
    options: WebviewOptions;
    claim(owner: any): void;
    release(owner: any): void;
    getInnerWebview(): Webview | undefined;
    layoutWebviewOverElement(element: HTMLElement, dimension?: Dimension): void;
}
